aboutsummaryrefslogtreecommitdiff
path: root/zenserver/config.h
diff options
context:
space:
mode:
authorStefan Boberg <[email protected]>2021-05-26 19:53:54 +0200
committerStefan Boberg <[email protected]>2021-05-26 19:53:54 +0200
commit61ac355b77782526b94f8aa5f923cca06927d34a (patch)
tree0bbeb182cc0265bad8d7a47a9f61bd50519d9af7 /zenserver/config.h
parentFixed up project.basic test to account for changes made to the project store ... (diff)
downloadzen-61ac355b77782526b94f8aa5f923cca06927d34a.tar.xz
zen-61ac355b77782526b94f8aa5f923cca06927d34a.zip
Added EnableMesh setting, fixed lifetime management
restructured handling of parent process lifetime management and added logic so that the parent process tracking works even when nothing else is using the asio I/O context
Diffstat (limited to 'zenserver/config.h')
-rw-r--r--zenserver/config.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/zenserver/config.h b/zenserver/config.h
index c96dc139a..fb866f134 100644
--- a/zenserver/config.h
+++ b/zenserver/config.h
@@ -9,12 +9,13 @@ struct ZenServerOptions
{
bool IsDebug = false;
bool IsTest = false;
- int BasePort = 1337; // Service listen port (used for both UDP and TCP)
- int OwnerPid = 0; // Parent process id (zero for standalone)
- std::string ChildId; // Id assigned by parent process (used for lifetime management)
- std::string LogId; // Id for tagging log output
- std::filesystem::path DataDir; // Root directory for state (used for testing)
- std::string FlockId; // Id for grouping test instances into sets
+ int BasePort = 1337; // Service listen port (used for both UDP and TCP)
+ int OwnerPid = 0; // Parent process id (zero for standalone)
+ std::string ChildId; // Id assigned by parent process (used for lifetime management)
+ std::string LogId; // Id for tagging log output
+ std::filesystem::path DataDir; // Root directory for state (used for testing)
+ std::string FlockId; // Id for grouping test instances into sets
+ bool EnableMesh = false; // Experimental p2p mesh discovery
};
void ParseGlobalCliOptions(int argc, char* argv[], ZenServerOptions& GlobalOptions);